% This file constructs the variables log_icp and log_go in mango_data.dat.
% log_icp is the log of a country's import share from Spain minus the log
% of Spain's domestic expenditure share. Shares are computed using ICP expenditure and GDP data. See data_description.pdf for
% details.
% log_go is the log of a country's import share from Spain minus log(1). Shares are computed using gross output data. See data_description.pdf for
% details.
% Note 1: this code will not run until the researcher obtains ICP data and
% saves it in a file titled exp_icp.txt.
% Note 2: variables log_go and log_icp constitute the difference of logged
% import share and a constant, C, which in theory represents Spain's domestic expenditure share. Since all regressions that use these
% variables include a constant, the value of C is irrelevant.

clear all

clc

close all

% Computing log_icp.
% Load bilateral trade flows in USD for year 2010 in apparel and footwear.

load flows2010.txt

flows=zeros(29,29);

for i=1:29
    for j=1:29
        entr=find(flows2010(:,2)==i & flows2010(:,1)==j);
        if entr>0
            flows(i,j)=flows2010(entr,3);
        end
    end
end

for i=1:29
    flows(i,i)=0;
end

% Load the expenditure on apparel and footwear in year 2010. This variable
% can be computed using the steps outlined in data_description.pdf. The
% variable must be computed individually by the researcher who must first
% obtain ICP expenditure data from the World Bank.

load exp_icp.txt

tradeshare = construct_tradeshare_go(flows, exp_icp);

flows_sp=zeros(1,29);

flows_sp(1,:)=tradeshare(end,:);

log_icp=log(flows_sp(1,:))'-log(flows_sp(1,end))';


clear flows entr flows_sp i j tradeshare


% Computing log_go.
% Load bilateral trade flows in USD for year 2008 in apparel and footwear.

load flows2008.txt

load go_29.txt

flows=reshape(flows2008(:,3),29,29);

for i=1:29
    flows(:,i)=flows(:,i)/go_29(i);
end

for i=1:29
   flows(i,i)=1; 
end

flows_sp=zeros(29,29);

flows_sp(end,:)=flows(end,:);

log_go=log(flows_sp(end,:))'-log(flows_sp(end,end))';